# NEKBDD: a nonparametric ensemble knowledge-based data-driven genetic network construction

Updated: August 23 2024

This repository contains code to reproduce the results of simulation and applications in

Chen-Po Liao, Hung-Ching Chang, Chuhsing Kate Hsiao. "NEKBDD: a nonparametric ensemble knowledge-based data-driven genetic network construction" (2024)
